==> tencentcloud-sdk-java-3.1.281-sources.jar: com/tencentcloudapi/btoe/v20210514/models/VerifyEvidenceBlockChainTxHashRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.btoe.v20210514.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class VerifyEvidenceBlockChainTxHashRequest extends AbstractModel{

    /**
    * ‘区块链交易hash，在"存证基本信息查询”中可以获取
    */
    @SerializedName("EvidenceTxHash")
    @Expose
    private String EvidenceTxHash;

    /**
     * Get ‘区块链交易hash，在"存证基本信息查询”中可以获取 
     * @return EvidenceTxHash ‘区块链交易hash，在"存证基本信息查询”中可以获取
     */
    public String getEvidenceTxHash() {
        return this.EvidenceTxHash;
    }

    /**
     * Set ‘区块链交易hash，在"存证基本信息查询”中可以获取
     * @param EvidenceTxHash ‘区块链交易hash，在"存证基本信息查询”中可以获取
     */
    public void setEvidenceTxHash(String EvidenceTxHash) {
        this.EvidenceTxHash = EvidenceTxHash;
    }

    public VerifyEvidenceBlockChainTxHashRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public VerifyEvidenceBlockChainTxHashRequest(VerifyEvidenceBlockChainTxHashRequest source) {
        if (source.EvidenceTxHash != null) {
            this.EvidenceTxHash = new String(source.EvidenceTxHash);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "EvidenceTxHash", this.EvidenceTxHash);

    }
}

==> tencentcloud-sdk-java-3.1.693-sources.jar: com/tencentcloudapi/btoe/v20210514/models/VerifyEvidenceBlockChainTxHashRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.btoe.v20210514.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class VerifyEvidenceBlockChainTxHashRequest extends AbstractModel{

    /**
    * 区块链交易 hash，在“存证基本信息查询（GetDepositInfo）”接口中可以获取。
    */
    @SerializedName("EvidenceTxHash")
    @Expose
    private String EvidenceTxHash;

    /**
     * Get 区块链交易 hash，在“存证基本信息查询（GetDepositInfo）”接口中可以获取。 
     * @return EvidenceTxHash 区块链交易 hash，在“存证基本信息查询（GetDepositInfo）”接口中可以获取。
     */
    public String getEvidenceTxHash() {
        return this.EvidenceTxHash;
    }

    /**
     * Set 区块链交易 hash，在“存证基本信息查询（GetDepositInfo）”接口中可以获取。
     * @param EvidenceTxHash 区块链交易 hash，在“存证基本信息查询（GetDepositInfo）”接口中可以获取。
     */
    public void setEvidenceTxHash(String EvidenceTxHash) {
        this.EvidenceTxHash = EvidenceTxHash;
    }

    public VerifyEvidenceBlockChainTxHashRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public VerifyEvidenceBlockChainTxHashRequest(VerifyEvidenceBlockChainTxHashRequest source) {
        if (source.EvidenceTxHash != null) {
            this.EvidenceTxHash = new String(source.EvidenceTxHash);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "EvidenceTxHash", this.EvidenceTxHash);

    }
}
